summaryrefslogtreecommitdiff
path: root/databases/rrdtool/patches/patch-at
blob: 75ee2b5474919094026e1053dee09213cd59e9dd (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
$NetBSD: patch-at,v 1.4 2003/02/16 23:09:00 seb Exp $

--- src/rrd_graph.c.orig	Fri Oct 11 18:39:47 2002
+++ src/rrd_graph.c
@@ -8,8 +8,10 @@
 #include "rrd_tool.h"
 #include "rrd_graph.h"
 #include <gd.h>
-#include <gdlucidan10.h>
-#include <gdlucidab12.h>
+#include <gdfonts.h>
+#include <gdfontt.h>
+/* #include <gdlucidan10.h> */
+/* #include <gdlucidab12.h> */
 #include <sys/stat.h>
 #ifdef WIN32
 #include <io.h>
@@ -24,8 +26,10 @@
 #include <locale.h>
 #endif
     
-#define SmallFont gdLucidaNormal10
-#define LargeFont gdLucidaBold12
+/* #define SmallFont gdLucidaNormal10 */
+/* #define LargeFont gdLucidaBold12 */
+#define SmallFont gdFontTiny
+#define LargeFont gdFontSmall
 
 /* #define DEBUG */
 
@@ -194,7 +198,6 @@ enum gf_en gf_conv(char *string){
 
 enum if_en if_conv(char *string){
     
-    conv_if(GIF,IF_GIF)
     conv_if(PNG,IF_PNG)
     conv_if(GD,IF_GD)
 
@@ -2396,9 +2399,6 @@ int lazy_check(image_desc_t *im){
     if ((fd = fopen(im->graphfile,"rb")) == NULL) 
       return 0; /* the file does not exist */
     switch (im->imgformat) {
-    case IF_GIF:
-	size = GifSize(fd,&(im->xgif),&(im->ygif));
-	break;
     case IF_PNG:
 	size = PngSize(fd,&(im->xgif),&(im->ygif));
 	break;
@@ -2673,9 +2673,6 @@ graph_paint(image_desc_t *im, char ***ca
 	}
     }
     switch (im->imgformat) {
-    case IF_GIF:
-	gdImageGif(gif, fo);    
-	break;
     case IF_PNG:
 	gdImagePng(gif, fo);    
 	break;
@@ -2809,7 +2806,7 @@ rrd_graph(int argc, char **argv, char **
     im.prt_c = 0;
     im.gdes_c = 0;
     im.gdes = NULL;
-    im.imgformat = IF_GIF; /* we default to GIF output */
+    im.imgformat = IF_PNG; /* we default to PNG output */
 
 im.bkg_image = NULL; /* do not put anything to background per default */
 im.ovl_image = NULL; /* do not use anything as overlay per default */